schemetools.SchemePair
======================

.. inheritance-diagram:: abjad.tools.schemetools.SchemePair.SchemePair.SchemePair
   :private-bases:

.. autoclass:: abjad.tools.schemetools.SchemePair.SchemePair.SchemePair

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.schemetools.SchemePair.SchemePair.SchemePair.format

Special Methods
---------------

.. automethod:: abjad.tools.schemetools.SchemePair.SchemePair.SchemePair.__delattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.schemetools.SchemePair.SchemePair.SchemePair.__eq__

   .. note:: Inherited from :py:class:`schemetools.Scheme <abjad.tools.schemetools.Scheme.Scheme.Scheme>`

.. automethod:: abjad.tools.schemetools.SchemePair.SchemePair.SchemePair.__ge__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.schemetools.SchemePair.SchemePair.SchemePair.__gt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.schemetools.SchemePair.SchemePair.SchemePair.__hash__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.schemetools.SchemePair.SchemePair.SchemePair.__le__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.schemetools.SchemePair.SchemePair.SchemePair.__lt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.schemetools.SchemePair.SchemePair.SchemePair.__ne__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.schemetools.SchemePair.SchemePair.SchemePair.__repr__

   .. note:: Inherited from :py:class:`schemetools.Scheme <abjad.tools.schemetools.Scheme.Scheme.Scheme>`

.. automethod:: abjad.tools.schemetools.SchemePair.SchemePair.SchemePair.__setattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.schemetools.SchemePair.SchemePair.SchemePair.__str__

   .. note:: Inherited from :py:class:`schemetools.Scheme <abjad.tools.schemetools.Scheme.Scheme.Scheme>`
